@@ -1,6 +1,7 @@
 """
 Call gitlab-emulator's code to execute a job
 """
+import sys
 import glob
 import os
 import shutil
@@ -8,11 +9,14 @@ import tempfile
 import subprocess
 import time
 import stat
+import traceback
 
 import requests
 import zipfile
 
-from .common import gethostname, iswindows
+import yaml
+
+from .common import gethostname, iswindows, generate_config, begin_log_section, end_log_section
 from .trace import TraceProxy
 from .consts import NAME, VERSION
 from unidecode import unidecode
@@ -196,14 +200,33 @@ def run(runner, job, docker):
         # clone the git repo defined in the job
         git = job["git_info"]
 
+        begin_log_section(trace, "git", "Source Control")
+
         trace.writeline("Cloning project..")
         trace_checkoutput(trace, ["git", "clone", git["repo_url"], build_dir], cwd=tempdir)
 
         # checkout the ref to build
         trace_checkoutput(trace, ["git", "checkout", "-f", get_variable(job, "CI_BUILD_REF")], cwd=build_dir_abs)
 
+        end_log_section(trace, "git")
+
+        # config_file
+        ci_cfg = get_variable(job, "CI_CONFIG_PATH")
+        if not ci_cfg:
+            begin_log_section(trace, "child-job", "Execute child job")
+            trace.writeline("Warning: CI_CONFIG_PATH is empty or unset")
+            trace.writeline("Warning: gitlab-python-runner child-pipeline support is experimental")
+            trace.writeline("Computing child job steps..")
+            new_config = generate_config(job)
+            ci_cfg = os.path.join(tempdir, "child-job.yml")
+            with(open(ci_cfg, "w")) as new_config_fh:
+                yaml.safe_dump(new_config, stream=new_config_fh)
+            with(open(ci_cfg, "r")) as new_config_fh:
+                for line in new_config_fh:
+                    trace.writeline("#" + line)
+            end_log_section(trace, "child-job")
         # load the config
-        ci_file = os.path.join(build_dir_abs,  get_variable(job, "CI_CONFIG_PATH"))
+        ci_file = os.path.join(build_dir_abs, ci_cfg)
         config = configloader.read(ci_file)
 
         # populate real vars
@@ -255,6 +278,11 @@ def run(runner, job, docker):
         return success
     except Exception as err:
         trace.writeline("Runner error: {}".format(err))
+        error_type, error, tb = sys.exc_info()
+        stacks = traceback.format_tb(tb)
+        for x in stacks:
+            trace.writeline(x)
+
 
     finally:
         clean(trace, tempdir, docker)
