@@ -42,6 +42,10 @@ parser.add_argument("--start", type=str,
                     help="Start the runner defined in the config file"
                     )
 
+parser.add_argument("--trace-http", default=False, action="store_true", dest="httpdebug",
+                    help="Log HTTP requests and responses for debugging purposes only"
+                    )
+
 parser.add_argument("--once", action="store_true", default=False,
                     help="Run only one job and then exit"
                     )
@@ -107,6 +111,10 @@ def run():
         sys.exit(0)
 
     if opts.start:
+
+        if opts.httpdebug:
+            common.set_trace_http_requests(True)
+
         config = common.parse_config(opts.start)
         os.chdir(config["dir"])
         extype = config["executor"]
